OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "ผู้ให้บริการอีเมลไม่ถูกต้อง",
    "%s has published the calendar »%s«" : "%s ได้เผยแพร่ปฏิทิน %s",
    "Unexpected error sending email. Please contact your administrator." : "เกิดข้อผิดพลาดไม่คาดคิดขณะส่งอีเมล โปรดติดต่อผู้ดูแล",
    "Successfully sent email to %1$s" : "ส่งอีเมลถึง %1$s สำเร็จ",
    "Hello," : "สวัสดี",
    "Open »%s«" : "เปิด »%s«",
    "Cheers!" : "ไชโย!",
    "Confirm" : "ยืนยัน",
    "Calendar" : "ปฏิทิน",
    "New event" : "เหตุการณ์ใหม่",
    "Today" : "วันนี้",
    "Day" : "วัน",
    "Week" : "สัปดาห์",
    "Month" : "เดือน",
    "Preview" : "ตัวอย่าง",
    "Copy link" : "คัดลอกลิงก์",
    "Edit" : "แก้ไข",
    "Delete" : "ลบ",
    "Export" : "ส่งออก",
    "Share link" : "แชร์ลิงค์",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "can edit" : "สามารถแก้ไข",
    "New calendar" : "สร้างปฏิทินใหม่",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Filename" : "ชื่อไฟล์",
    "Cancel" : "ยกเลิก",
    "Automatic" : "อัตโนมัติ",
    "List view" : "มุมมองแบบรายการ",
    "Actions" : "การกระทำ",
    "Location" : "ตำแหน่งที่อยู่",
    "Description" : "รายละเอียด",
    "to" : "ถึง",
    "Add" : "เพิ่ม",
    "Monday" : "วันจันทร์",
    "Tuesday" : "วันอังคาร",
    "Wednesday" : "วันพุธ",
    "Thursday" : "วันพฤหัสบดี",
    "Friday" : "วันศุกร์",
    "Saturday" : "วันเสาร์",
    "Sunday" : "วันอาทิตย์",
    "Save" : "บันทึก",
    "Update" : "อัพเดท",
    "Your email address" : "ที่อยู่อีเมลของคุณ",
    "Email" : "อีเมล",
    "Unknown" : "ไม่ทราบ",
    "Accept" : "ยอมรับ",
    "Decline" : "ลดลง",
    "Tentative" : "ชั่วคราว",
    "Send email" : "ส่งอีเมล",
    "Repeat" : "ทำซ้ำ",
    "never" : "ไม่ต้องเลย",
    "after" : "หลัง",
    "More" : "เพิ่มเติม",
    "Pick a date" : "เลือกวันที่",
    "Global" : "ทั่วไป",
    "Personal" : "ส่วนตัว",
    "Details" : "รายละเอียด",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Close" : "ปิด",
    "Anniversary" : "วันครบรอบ",
    "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
    "Daily" : "รุ่นรายวัน",
    "Weekly" : "รายสัปดาห์",
    "Next" : "ถัดไป",
    "Other" : "อื่น ๆ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Status" : "สถานะ",
    "Confirmed" : "ได้รับการยืนยันแล้ว",
    "Commuting" : "กำลังเดินทาง",
    "Presentation" : "งานนำเสนอ",
    "Office" : "สำนักงาน",
    "Mail" : "จดหมาย",
    "Birthday" : "วันเกิด"
},
"nplurals=1; plural=0;");
